# -*- coding: utf-8 -*-
from __future__ import absolute_import, division, print_function

from .client import AWSFederationClientCmd

__all__ = ['AWSFederationClientCmd']

__version__ = '340.214'
